import { ArDateMasks as r, ArDropdownVariants as n, ArLabelValueVariants as e, ArWebPageLayout as a } from "../types/enums.js";
const s = {
  ATOMS: {
    meta: {
      label: "Foundational",
      description: "Basic components that constitute more sophisticated ones"
    },
    components: [
      {
        name: "Accordion",
        props: [
          "classes",
          "variant",
          "data",
          "isRemovable",
          "firstExpanded",
          "appearance"
        ],
        variants: {
          variant: ["limited", "free"],
          appearance: ["stacked", "flat"],
          isRemovable: [!0, !1],
          firstExpanded: [!0, !1]
        }
      },
      {
        name: "AdvancedColorPicker",
        props: []
      },
      {
        name: "Alert",
        props: ["classes", "position", "type", "message", "closeable"],
        variants: {
          position: [
            "top-left",
            "top-right",
            "bottom-left",
            "bottom-right",
            "top-center",
            "bottom-center"
          ],
          type: ["success", "warning", "error", "information"],
          closeable: [!0, !1]
        }
      },
      {
        name: "Badge",
        props: ["size", "text", "type", "shadow"],
        variants: {
          size: ["small", "medium", "large"],
          type: ["inprogress", "complete", "deferred", "atrisk"],
          shadow: [!0, !1]
        }
      },
      {
        name: "Breadcrumb",
        props: [],
        variants: {},
        uses: [{ name: "Button", hierarchy: "ATOMS" }]
      },
      {
        name: "BrowserIncompatibility",
        props: [],
        variants: {},
        uses: [
          { name: "Alert", hierarchy: "ATOMS" },
          { name: "Icon", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Button",
        props: ["size", "variant", "icon"],
        variants: {
          size: ["xsmall", "small", "medium", "large"],
          variant: [
            "primary",
            "secondary",
            "tertiary",
            "danger",
            "warning",
            "success",
            "info",
            "dark",
            "light",
            "link",
            "link-native",
            "link-hover"
          ],
          content: ["Click me"],
          preIcon: ["io.IoMdHelp", "fa.FaSearch"],
          postIcon: ["io.IoMdHelp", "fa.FaCheckSquare"],
          splitOptions: [!0, !1]
        },
        uses: [
          { name: "List", hierarchy: "ATOMS" },
          { name: "PopoverV2", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Calendar",
        props: ["startDate", "minDate", "maxDate", "hasTimeControls"],
        variants: {
          hasTimeControls: [!0, !1],
          miniMode: [!0, !1],
          allowEventSetting: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Badge", hierarchy: "ATOMS" },
          { name: "Dropdown", hierarchy: "ATOMS" },
          { name: "Popover", hierarchy: "ATOMS" },
          { name: "SegmentedControl", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "TimeInput", hierarchy: "ATOMS" },
          { name: "TextArea", hierarchy: "ATOMS" },
          { name: "Toggle", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Carousel",
        props: [],
        variants: {}
      },
      {
        name: "Checkbox",
        props: ["id", "label", "type", "onChange"],
        variants: {
          type: ["TOGGLE", "CHECKBOX"]
        },
        uses: [{ name: "Toggle", hierarchy: "ATOMS" }]
      },
      {
        name: "ColorPicker",
        props: ["id", "label", "onChange", "value"],
        variants: {
          label: ["Click"]
        }
      },
      {
        name: "ContextMenu",
        type: "HOC",
        children: ["bg"],
        props: [],
        variants: {},
        test: { background: "Balloon" },
        uses: [
          { name: "InlineMenu", hierarchy: "ATOMS" },
          { name: "List", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "DateInput",
        props: [],
        variants: {}
      },
      {
        name: "DatePicker",
        props: ["id", "label"],
        variants: {
          label: ["Date"],
          allowEventSetting: [!0, !1]
        },
        uses: [
          { name: "Calendar", hierarchy: "ATOMS" },
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Dropdown", hierarchy: "ATOMS" },
          { name: "Popover", hierarchy: "ATOMS" },
          { name: "SegmentedControl", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "TimeInput", hierarchy: "ATOMS" },
          { name: "TextArea", hierarchy: "ATOMS" },
          { name: "Toggle", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "DateRangePicker",
        props: ["id", "label"],
        variants: {
          label: ["Date Range"],
          closeOnEndSelect: [!0, !1],
          mask: [r.LONGDATE, r.SHORTDATE]
        },
        uses: [
          { name: "Calendar", hierarchy: "ATOMS" },
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Dropdown", hierarchy: "ATOMS" },
          { name: "Popover", hierarchy: "ATOMS" },
          { name: "SegmentedControl", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "TimeInput", hierarchy: "ATOMS" },
          { name: "TextArea", hierarchy: "ATOMS" },
          { name: "Toggle", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Dropdown",
        props: ["isMultiSelect", "hasBorder", "showCheckBoxes"],
        variants: {
          isMultiSelect: [!0, !1],
          hasBorder: [!0, !1],
          showCheckBoxes: [!0, !1],
          variant: [
            n.SELECTIONSASLINKS,
            n.SELECTIONSASPILLS
          ],
          hideDropdownMarker: [!0, !1],
          isDisabled: [!0, !1],
          version: ["v1", "v2"]
        },
        uses: [
          { name: "List", hierarchy: "ATOMS" },
          { name: "Popover", hierarchy: "ATOMS" },
          { name: "PopoverV2", hierarchy: "ATOMS" },
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Pillbox", hierarchy: "ATOMS" },
          { name: "Pill", hierarchy: "ATOMS" },
          { name: "Portal", hierarchy: "MOLECULES" }
        ]
      },
      {
        name: "PickerRange",
        props: [],
        variants: {}
      },
      {
        name: "DetailsPanel",
        props: [],
        variants: {}
      },
      {
        name: "Dialog",
        props: [],
        variants: {}
      },
      {
        name: "Draggable",
        props: [],
        variants: {}
      },
      {
        name: "FacetedFilter",
        props: [],
        variants: {}
      },
      {
        name: "InlineMenu",
        props: [],
        test: { background: "Balloon" },
        variants: {},
        uses: [{ name: "List", hierarchy: "ATOMS" }]
      },
      {
        name: "Icon",
        props: [
          "src",
          "size",
          "classes",
          "containerClasses",
          "height",
          "width"
        ],
        variants: {
          src: ["ai/AiFillAccountBook", "ai/AiFillCaretUp"],
          size: ["1rem", "5rem", "10rem", "64px", "15%"],
          color: ["red", "green", "purple", "#3538f6", "rgb(255, 90, 23)"]
        }
      },
      {
        name: "Image",
        props: ["image", "alt", "title"],
        variants: {
          image: ["https://picsum.photos/200/300"],
          flipHorizontal: [!0, !1],
          flipVertical: [!0, !1],
          rotateBy: [30, -75],
          opacity: [0.3, 0.7],
          brightness: [0.6, 2.5],
          contrast: [0.6, 2.5],
          saturate: [0.6, 2.5],
          blur: [2, 10],
          grayscale: [0.3, 0.7],
          sepia: [0.3, 0.7],
          isBackground: [!0, !1],
          fill: [!0, !1],
          preserveAspectRatio: [!0, !1]
        }
      },
      {
        name: "LabelValue",
        props: [],
        variants: {
          variant: [
            e.FLAT,
            e.STACKED,
            e.FLATBOXED,
            e.STACKBOXED
          ]
        }
      },
      {
        name: "LayoutGenerator",
        props: [],
        variants: {
          variant: [
            a.TWOCOL,
            a.THREECOL,
            a.TABBED,
            a.STACKED,
            a.HEROLINEARCONTENTBLOCKS,
            a.HEROSTAGGEREDARCONTENTBLOCKS,
            a.HEROSTAGGEREDREVERSEDARCONTENTBLOCKS,
            a.GRID,
            a.FULL,
            a.CAROUSEL,
            a.CARD,
            a.SPLIT,
            a.CUSTOM
          ],
          demoChildCount: [1, 2, 3, 5, 10, 17, 20, 28],
          hasHeader: [!0, !1],
          hasFooter: [!0, !1],
          hasDrawer: [!0, !1],
          hasSidepanel: [!0, !1]
        }
      },
      {
        name: "LayoutCreator",
        props: [],
        variants: {},
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Dropdown", hierarchy: "ATOMS" },
          { name: "List", hierarchy: "ATOMS" },
          { name: "PopoverV2", hierarchy: "ATOMS" },
          { name: "Pill", hierarchy: "ATOMS" },
          { name: "Wizard", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "Toggle", hierarchy: "ATOMS" },
          { name: "Slot", hierarchy: "ATOMS" },
          { name: "Layout", hierarchy: "ATOMS" },
          { name: "Resizable", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Layout",
        props: [],
        variants: {
          showControls: [!0, !1],
          gridTemplate: [
            `"ga-8deaf13f-2640-4f09-8d7f-3f6df63cae57 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-db1627de-d2e5-4edf-83e1-70305e87787a" minmax(auto, 1fr)
          "ga-f0a3f29d-8e96-4ca4-bbe3-be6ff38d7c04 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-e45464a6-8c43-4f73-b0dc-f7068eeb6453" minmax(auto, 1fr)
          "ga-a94190e8-0153-42d1-94b2-7f16748c8851 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-5f0e3e9c-1598-435f-9e87-0590cd360ada" minmax(auto, 1fr)
          "ga-1dbe7142-eff1-4f0a-ac57-1aecb06eab08 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-e1eb5ec1-c534-4186-8487-328eb5688d6f" minmax(auto, 1fr)
          "ga-f1aca4b5-7030-4610-a565-10f887341f99 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-73e373f1-710f-4ef6-b42e-ca8914979fb7 ga-f253dc94-99e6-4c7d-90bc-caa66d215abe" minmax(auto, 1fr) / 1fr 1fr 1fr 1fr 1fr`,
            `"ga-29341a53-cd8a-4b0d-82bc-fe38e0d99a4d ga-b6cd0d44-60a6-4e32-9102-3e8222a5167b ga-e381bf31-89e2-437c-8bcf-7de2cabe448f ga-3b6c777e-edad-4572-b601-e4ac516fca37 ga-70a7981a-d23d-44f6-8c6a-b60594e55a7f" minmax(auto, 1fr)
          "ga-693b8528-5a6d-4f53-a624-328a487fdee9 ga-02fc4640-d7ce-4492-9e4a-83ce85db1372 ga-c9c9b912-6ae7-442c-8c25-43607dec220a ga-8573cdb2-a7a6-4495-91c8-4c0cce5e81e7 ga-715bcef5-5fe1-4c86-9238-ca7dfcb1d4c4" minmax(auto, 1fr)
          "ga-adcede1e-e172-434a-995c-42b36554efcc ga-d7402be3-e4b4-4ec7-93e3-107b043ccff6 ga-8fc5f194-b81b-4de9-a3cd-436a2f523715 ga-44f30fa2-6504-41d2-b8aa-34282d89fc0b ga-e362e9c1-a9a8-4be1-8547-9b8048792dcc" minmax(auto, 1fr)
          "ga-35c7474c-66e6-4452-9935-6642602ee07f ga-8a6d94e7-1b10-47aa-8d46-32d4754278b9 ga-935cf05f-b79a-487c-bf73-0962cd1586a4 ga-896f8cbf-3302-408b-8a26-c74ae8885ac3 ga-a38bcb1d-6577-41db-b53a-3085661edb98" minmax(auto, 1fr)
          "ga-a7d74f0b-e5a5-4962-9037-89a9ac9fb165 ga-c3efb929-4730-4c36-9f25-dfb259659c37 ga-ba80a739-453d-4d2c-b851-d6fde75b2ff1 ga-2b8b97e9-de10-4053-9396-30fe3dc14dc9 ga-70ae5500-a3f2-4e95-8001-e0f7f28258f4" minmax(auto, 1fr) / 1fr 1fr 1fr 1fr 1fr`
          ],
          mode: ["build", "release"]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "BuilderSlot", hierarchy: "ATOMS" },
          { name: "Resizable", hierarchy: "ATOMS" },
          { name: "PopoverV2", hierarchy: "ATOMS" },
          { name: "LayoutControlPanel", hierarchy: "ATOMS" },
          { name: "BuilderLayout", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "LearnLink",
        props: [],
        variants: {}
      },
      {
        name: "Link",
        props: [],
        variants: {}
      },
      {
        name: "List",
        props: ["showCheckBoxes", "isMultiSelect"],
        variants: {
          showCheckBoxes: [!0, !1],
          isMultiSelect: [!0, !1],
          variant: ["link", "flat"]
        },
        uses: [{ name: "Button", hierarchy: "ATOMS" }]
      },
      {
        name: "LoadableIcon",
        props: [
          "src",
          "size",
          "classes",
          "containerClasses",
          "height",
          "width"
        ],
        variants: {
          icon: ["ai/AiFillAccountBook", "ai/AiFillCaretUp"],
          size: ["1rem", "5rem", "10rem", "64px", "15%"],
          color: ["red", "green", "purple", "#3538f6", "rgb(255, 90, 23)"]
        }
      },
      {
        name: "Modal",
        props: [],
        variants: {
          show: [!0, !1],
          isSticky: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "Portal", hierarchy: "MOLECULES" }
        ]
      },
      {
        name: "Notification",
        props: [],
        variants: {}
      },
      {
        name: "NumericStepper",
        props: [],
        variants: {}
      },
      {
        name: "Pagination",
        props: ["data", "maxPillsToShow"],
        variants: {
          maxPillsToShow: [3, 5, 10]
        }
      },
      {
        name: "Picklist",
        props: [],
        variants: {}
      },
      {
        name: "Pill",
        props: [],
        variants: {}
      },
      {
        name: "Pillbox",
        props: [],
        variants: {}
      },
      {
        name: "Popover",
        type: "HOC",
        children: ["anchor", "popover"],
        props: ["position", "trigger"],
        variants: {
          position: [
            "auto",
            "left",
            "right",
            "top",
            "bottom",
            "left-top",
            "left-center",
            "left-bottom",
            "right-top",
            "right-center",
            "right-bottom",
            "top-left",
            "top-center",
            "top-right",
            "bottom-left",
            "bottom-center",
            "bottom-right"
          ],
          trigger: ["click", "hover"],
          version: ["v1", "v2"],
          hideMarker: [!0, !1],
          popAtPointer: [!0, !1],
          animation: ["expand-shrink", "fade"],
          preserveMarkerSpace: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "PopoverV1", hierarchy: "ATOMS" },
          { name: "PopoverV2", hierarchy: "ATOMS" },
          { name: "Portal", hierarchy: "MOLECULES" }
        ]
      },
      {
        name: "Loader",
        props: ["type", "label", "size"],
        variants: {
          size: ["small", "regular", "large"],
          label: ["Loading Users...", "Submitting Report..."],
          type: ["bar", "circle", "custom", "shapes"]
        }
      },
      {
        name: "ProgressiveBarChart",
        props: [],
        variants: {
          maxLabelCharLength: [3, 5, 8, 10]
        }
      },
      {
        name: "ProgressIndicator",
        props: [],
        variants: {}
      },
      {
        name: "ProgressStepper",
        props: [],
        variants: {}
      },
      {
        name: "Radio",
        props: [],
        variants: {}
      },
      {
        name: "ScrollPagination",
        type: "HOC",
        children: ["list"],
        props: [],
        variants: {},
        uses: [
          { name: "Loader", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "SearchField",
        props: [],
        variants: {},
        uses: [
          { name: "TypeAhead", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" },
          { name: "Loader", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "SecondaryNavigation",
        props: [],
        variants: {}
      },
      {
        name: "SegmentedControl",
        props: [],
        variants: {}
      },
      {
        name: "Select",
        props: [],
        variants: {}
      },
      {
        name: "SelectionPill",
        props: ["classes", "context", "data", "onClick", "size"],
        variants: {
          size: ["small", "medium", "large"]
        }
      },
      {
        name: "Slider",
        props: [],
        variants: {}
      },
      {
        name: "Splitter",
        props: [],
        variants: {}
      },
      {
        name: "Swiper",
        props: [],
        variants: {}
      },
      {
        name: "Tab",
        props: [
          "label",
          "data",
          "deletable",
          "id",
          "isActive",
          "onSelect",
          "size",
          "variant"
        ],
        variants: {
          deletable: [!0, !1],
          isActive: [!0, !1],
          size: ["compact", "comfortable"],
          variant: ["classic", "modern"]
        }
      },
      {
        name: "TabBar",
        props: ["activeId", "data", "onTabChanged", "size", "variant"],
        variants: {
          size: ["compact", "comfortable"],
          variant: ["classic", "modern"]
        },
        uses: [{ name: "Tab", hierarchy: "ATOMS" }]
      },
      {
        name: "Table",
        props: [],
        variants: {
          layout: ["comfortable", "compact", "normal"]
        }
      },
      {
        name: "Tag",
        props: [],
        variants: {}
      },
      {
        name: "TextArea",
        props: [],
        variants: {}
      },
      {
        name: "TreeList",
        props: ["data", "firstExpanded", "noSearch", "title", "onItemSelect"],
        variants: {
          isDraggable: [!0, !1]
        },
        uses: [
          { name: "SearchField", hierarchy: "ATOMS" },
          { name: "TextInput", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Mask",
        props: [],
        variants: {}
      },
      {
        name: "TextInput",
        props: ["type", "label", "placeholder", "labelPlacement"],
        variants: {
          type: [
            "text",
            "password",
            "file",
            "radio",
            "color",
            "checkbox",
            "range",
            "date"
          ],
          label: ["Username", !1],
          placeholder: ["Address"],
          labelPlacement: ["left", "top", "right", "bottom"],
          subtitle: [
            "This is a one time question and is used to tailer your experience"
          ],
          size: ["small", "large"],
          action: [!0, !1]
        }
      },
      {
        name: "TimeEntry",
        props: [],
        variants: {}
      },
      {
        name: "Toggle",
        props: [],
        variants: {}
      },
      {
        name: "Toolbar",
        props: [],
        variants: {}
      },
      {
        name: "Tooltip",
        props: [],
        variants: {}
      },
      {
        name: "TypeAhead",
        props: [],
        variants: {
          isMultiSelect: [!0, !1],
          value: ["Test1"],
          inputValue: ["st1", "tes"],
          assistiveContent: ["Provide input to determise project structure"],
          outsourceMultiSelections: [!0, !1]
        },
        uses: [
          { name: "TextInput", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" },
          { name: "Pillbox", hierarchy: "ATOMS" },
          { name: "Pill", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Uploader",
        props: [],
        variants: {}
      },
      {
        name: "Widget",
        props: ["header", "content"],
        variants: {}
      },
      {
        name: "Wizard",
        props: [
          "stages",
          "activeStage",
          "onStageChange",
          "onComplete",
          "onCancel"
        ],
        variants: {
          navigationType: [
            "standard",
            "overlay",
            "overlay-prominent",
            "external"
          ],
          title: ["Add User", "Create Project"],
          hideStatusBar: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "WizardModal",
        variants: {
          hideStatusBar: [!0, !1],
          show: [!0, !1],
          isSticky: [!0, !1]
        },
        uses: [
          { name: "Button", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" },
          { name: "Modal", hierarchy: "ATOMS" },
          { name: "Wizard", hierarchy: "ATOMS" },
          { name: "Portal", hierarchy: "MOLECULES" }
        ]
      }
    ]
  },
  MOLECULES: {
    meta: {
      label: "Features, pages, use cases",
      description: "Use these components for special cases like about us section, blog etc."
    },
    components: [
      {
        name: "AboutUs",
        props: [],
        variants: {}
      },
      {
        name: "Application",
        props: [],
        variants: {}
      },
      {
        name: "ArIconsViewer",
        props: [],
        variants: {
          hasSearch: [!0, !1],
          hasViewSelector: [!0, !1],
          isDraggable: [!0, !1]
        },
        uses: [
          { name: "ScrollPagination", hierarchy: "ATOMS" },
          { name: "SegmentedControl", hierarchy: "ATOMS" },
          { name: "PopoverV2", hierarchy: "ATOMS" },
          { name: "SearchField", hierarchy: "ATOMS" },
          { name: "TypeAhead", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Banner",
        props: [],
        variants: {}
      },
      {
        name: "Benefits",
        props: [],
        variants: {}
      },
      {
        name: "Blog",
        props: [],
        variants: {}
      },
      {
        name: "Brands",
        props: [],
        variants: {}
      },
      {
        name: "Breadcrumbs",
        props: [],
        variants: {}
      },
      {
        name: "CTA",
        props: [],
        variants: {}
      },
      {
        name: "Card",
        props: [],
        variants: {}
      },
      {
        name: "Careers",
        props: [],
        variants: {}
      },
      {
        name: "Contact",
        props: [],
        variants: {}
      },
      {
        name: "Content",
        props: [],
        variants: {}
      },
      {
        name: "Cookies",
        props: [],
        variants: {}
      },
      {
        name: "Dashboard",
        props: [],
        variants: {}
      },
      {
        name: "Download",
        props: [],
        variants: {}
      },
      {
        name: "Ecomm_Orders",
        props: [],
        variants: {}
      },
      {
        name: "Ecomm_Products",
        props: [],
        variants: {}
      },
      {
        name: "Empty",
        props: [],
        variants: {}
      },
      {
        name: "FAQ",
        props: [],
        variants: {}
      },
      {
        name: "Features",
        props: [],
        variants: {}
      },
      {
        name: "Footer",
        props: [],
        variants: {}
      },
      {
        name: "Form",
        props: [],
        variants: {}
      },
      {
        name: "Gallery",
        props: [],
        variants: {}
      },
      {
        name: "GraphTiles",
        props: [],
        variants: {}
      },
      {
        name: "Graph",
        props: [],
        variants: {}
      },
      {
        name: "HTTPCode",
        props: [],
        variants: {}
      },
      {
        name: "Hero",
        props: [],
        variants: {},
        uses: [{ name: "Button", hierarchy: "ATOMS" }]
      },
      {
        name: "HowItWorks",
        props: [],
        variants: {}
      },
      {
        name: "InstaPhotos",
        props: [],
        variants: {}
      },
      {
        name: "Integrations",
        props: [],
        variants: {}
      },
      {
        name: "LogoClouds",
        props: [],
        variants: {}
      },
      {
        name: "Newsletter",
        props: [],
        variants: {}
      },
      {
        name: "Notifications",
        props: [],
        variants: {}
      },
      {
        name: "pagination",
        props: [],
        variants: {}
      },
      {
        name: "portfolio",
        props: [],
        variants: {}
      },
      {
        name: "Pricing",
        props: [],
        variants: {}
      },
      {
        name: "ProductInfo",
        props: [],
        variants: {}
      },
      {
        name: "Projects",
        props: [],
        variants: {}
      },
      {
        name: "Reviews",
        props: [],
        variants: {}
      },
      {
        name: "RichText",
        props: [],
        variants: {}
      },
      {
        name: "Services",
        props: [],
        variants: {}
      },
      {
        name: "SignInUp",
        props: [],
        variants: {}
      },
      {
        name: "Snackbar",
        props: [],
        variants: {}
      },
      {
        name: "Stats",
        props: [],
        variants: {}
      },
      {
        name: "Steps",
        props: [],
        variants: {}
      },
      {
        name: "Table",
        props: [],
        variants: {}
      },
      {
        name: "Team",
        props: [],
        variants: {}
      },
      {
        name: "Testimonials",
        props: [],
        variants: {}
      },
      {
        name: "Toast",
        props: [],
        variants: {}
      },
      {
        name: "TransferShuttle",
        props: [],
        variants: {},
        uses: [
          { name: "Widget", hierarchy: "MOLECULES" },
          { name: "List", hierarchy: "ATOMS" },
          { name: "Button", hierarchy: "ATOMS" },
          { name: "LoadableIcon", hierarchy: "ATOMS" }
        ]
      },
      {
        name: "Users",
        props: [],
        variants: {}
      }
    ]
  }
};
export {
  s as default
};
