import { Moment } from "moment";
import { ChangeEvent, HTMLInputTypeAttribute, MouseEventHandler, ReactNode, FocusEvent, CSSProperties, ReactElement, Ref, ComponentType, RefObject } from "react";
import { ArAccordionStyles, ArAccordionVariants, ArAlertType, ArAnimations, ArBadgeType, ArButtonTypes, ArButtonVariants, ArCalViews, ArComponentLevels, ArDateMasks, ArDefaultLoginPage, ArDirections, ArDisplayTypes, ArDndItemTypes, ArDropdownVariants, ArHeaderSlots, ArIconTileTypes, ArLabelValueVariants, ArListVariants, ArLoaderTypes, ArLoginProviders, ArMonthSelectorViews, ArPageTriggers, ArPillSizes, ArPlacement, ArPopoverPositions, ArPopoverTriggers, ArSizes, ArSlotViewMode, ArTableLayouts, ArVisualizationTypes, ArWebPageLayout, ArWizardNavigationTypes } from "./enums";
import { AppNavigatorDataType, BreadCrumbData, CalendarDate, Config, Event, FrameContentDefinition, GridSpecs, ListActionItem, ListItemContent, Locale, Namespace, OptionType, PageInfoType, PresetDefinition, ProgressiveChartData, SearchItem, SegmentData, SlotDescriptor, TableRowItem, Task, ToolItemConfig, TreeListData, User, WidgetActionItem, WizardStage } from "./entity.interface";
import { IconResponse, PageItem } from "./iconresponse.interface";
import { AnimationHandler, ArrayType, CheckBoxTypes, DateFormat, FunctionType, ObjectType, PRIMITIVES, StopSwipingHandler, SwipeAnimationHandler } from "./types";
import { CalendarInstance } from "../utils/dateHelper";
import { Column } from "react-table";
export interface BaseProps {
    children?: ReactNode;
    classes?: string;
    containerClasses?: string;
    childClasses?: string;
    demo?: boolean;
    slot?: string;
    style?: CSSProperties;
    theme?: string;
    version?: string;
}
export interface FormInputProps extends BaseProps {
    ariaLabel?: string;
    assistiveContent?: JSX.Element | {
        content: string;
        onClick: MouseEventHandler<HTMLButtonElement>;
    };
    id?: string;
    isDisabled?: boolean;
    label?: string;
    labelClasses?: string;
    labelPlacement?: ArPlacement;
    name?: string;
    onBlur?: (event: ChangeEvent<unknown>) => void | FunctionType;
    onChange?: FunctionType;
    onFocus?: (event: FocusEvent<unknown>) => void | FunctionType;
    required?: boolean;
    size?: ArSizes;
    value?: string | number | boolean | ObjectType | Array<unknown> | null;
}
export interface ReleaseSlotProps extends BaseProps {
    config: SlotDescriptor;
    content?: ReactNode;
}
export interface BuilderSlotProps extends SlotProps {
}
export interface SlotToolsProps extends BaseProps {
    config: SlotDescriptor;
    mode?: ArSlotViewMode;
    controlsEnabled?: boolean;
    horizontalSplitHandler?: FunctionType;
    verticalSplitHandler?: FunctionType;
    mergeHandler?: FunctionType;
    rowInsertHandler?: FunctionType;
    columnInsertHandler?: FunctionType;
    rowDeleteHandler?: FunctionType;
    columnDeleteHandler?: FunctionType;
    rowSelectHandler?: FunctionType;
    columnSelectHandler?: FunctionType;
}
export interface ReleaseLayoutProps extends BaseProps {
    gridTemplate?: string;
    slots?: Array<SlotDescriptor>;
    slotRenderer?: FunctionType;
    mode?: LayoutProps["mode"];
}
export interface BuilderLayoutProps extends LayoutProps {
}
export interface LayoutControlPanelProps extends BaseProps {
    showControls?: boolean;
    setShowControls: FunctionType;
    slots?: Array<SlotDescriptor>;
    splitEnabled?: boolean;
    mergeEnabled?: boolean;
    rowDeleteEnabled?: boolean;
    columnDeleteEnabled?: boolean;
    undoEnabled?: boolean;
    redoEnabled?: boolean;
    selectionOnlyModeEnabled?: boolean;
    show?: boolean;
    horizontalSplitHandler: FunctionType;
    verticalSplitHandler: FunctionType;
    mergeHandler: FunctionType;
    rowInsertHandler: FunctionType;
    columnInsertHandler: FunctionType;
    rowDeleteHandler: FunctionType;
    columnDeleteHandler: FunctionType;
    undoHandler: FunctionType;
    redoHandler: FunctionType;
    enableSelectionOnlyMode: FunctionType;
}
export interface ResizableProps extends BaseProps {
    componentName?: string;
    children?: ReactNode;
    display?: ArDisplayTypes;
    directions?: Array<ArDirections>;
    reClasses?: string;
    [key: string]: any;
}
export interface LayoutProps extends BaseProps {
    gridSpecs?: GridSpecs;
    slots?: Array<SlotDescriptor>;
    rowHeights?: string | Array<string>;
    colWidths?: string | Array<string>;
    mode?: "build" | "preview" | "release";
    slotDropHandler?: FunctionType;
    onLayoutChange?: FunctionType;
    gridTemplate?: string;
    onSlotSelect?: FunctionType;
    showControls?: boolean;
    slotRenderer?: FunctionType;
    showPanels?: boolean;
}
export interface SlotProps extends BaseProps {
    childRef?: RefObject<HTMLDivElement>;
    config: SlotDescriptor;
    isFirst?: boolean;
    isLast?: boolean;
    mode?: ArSlotViewMode;
    onClick?: FunctionType;
    controlsEnabled?: boolean;
    selectionOnlyModeEnabled?: boolean;
    acceptDropTypes?: Array<string>;
    layoutMode?: LayoutProps["mode"];
    content?: ReactNode;
    dropHandler?: FunctionType;
    horizontalSplitHandler?: FunctionType;
    verticalSplitHandler?: FunctionType;
    mergeHandler?: FunctionType;
    rowInsertHandler?: FunctionType;
    columnInsertHandler?: FunctionType;
    rowDeleteHandler?: FunctionType;
    columnDeleteHandler?: FunctionType;
    rowSelectHandler?: FunctionType;
    columnSelectHandler?: FunctionType;
}
export interface LayoutCreatorProps extends BaseProps {
}
export interface ScrollPaginationProps extends BaseProps {
    apiEndpoint?: string;
    component?: ComponentType<any>;
    data?: Array<any>;
    dataSetter?: FunctionType;
    filters?: {
        [key: string]: string;
    };
    gridClasses?: string;
    gridStyles?: CSSProperties;
    limit?: number;
    threshold?: number;
}
export interface ArIconsViewerProps extends BaseProps {
    view?: SegmentData;
    hasSearch?: boolean;
    hasViewSelector?: boolean;
    isDraggable?: boolean;
}
export interface ProgressiveBarChartProps extends BaseProps {
    data: ProgressiveChartData;
    interval?: number;
    maxLabelCharLength?: number;
    shouldSortX?: boolean;
    title?: string;
}
export interface DroppableProps extends BaseProps {
    acceptTypes?: ArDndItemTypes | string | Array<string | ArDndItemTypes>;
    dropHandler: FunctionType;
}
export interface DraggableProps extends BaseProps {
    itemType?: ArDndItemTypes | string;
    canDrag?: boolean;
    itemData?: any;
}
export interface TransferShuttleProps extends BaseProps {
    hasSearch?: boolean;
    leftHeader?: string;
    rightHeader?: string;
    leftList: Array<ListItemContent>;
    rightList?: Array<ListItemContent>;
    onChange?: FunctionType;
}
export interface ArmcoIamProviderProps extends BaseProps {
    defaultPage?: ArDefaultLoginPage;
}
export interface StuffleIamProviderProps extends BaseProps {
    defaultPage: ArDefaultLoginPage;
}
export interface ImageProps extends BaseProps {
    image: string;
    alt?: string;
    title?: string;
    fill?: boolean;
    preserveAspectRatio?: boolean;
    flipHorizontal?: boolean;
    flipVertical?: boolean;
    rotateBy?: number;
    opacity?: number;
    brightness?: number;
    contrast?: number;
    saturate?: number;
    blur?: number;
    grayscale?: number;
    sepia?: number;
    isBackground?: boolean;
    customBgZIndex?: number;
}
export interface PopoverV2Props extends BaseProps {
    animation?: ArAnimations | Array<ArAnimations>;
    children: Array<JSX.Element | null>;
    contentClasses?: string;
    contentMatchAnchorWidth?: boolean;
    hideMarker?: boolean;
    isOpen?: boolean;
    onAnchorClick?: FunctionType;
    position?: ArPopoverPositions;
    popAtClick?: boolean;
    transition?: boolean;
    trigger?: ArPopoverTriggers;
}
export interface PopoverV1Props extends BaseProps {
    animation?: ArAnimations;
    children: Array<JSX.Element | null>;
    contentClasses?: string;
    contentMatchAnchorWidth?: boolean;
    hideMarker?: boolean;
    isOpen?: boolean;
    onAnchorClick?: FunctionType;
    position?: ArPopoverPositions;
    popAtClick?: boolean;
    transition?: boolean;
    trigger?: ArPopoverTriggers;
}
export interface PortalProps extends BaseProps {
    children: ReactNode;
    container?: HTMLElement | null;
    position?: DOMRect | null;
    styles?: CSSProperties;
}
export interface HeaderProps extends BaseProps {
    isFluid?: boolean;
    isSticky?: boolean;
    children?: JSX.Element | readonly (JSX.Element | null)[] | null;
    order?: [ArHeaderSlots];
}
export interface LayoutGeneratorProps extends BaseProps {
    children?: ReactNode;
    cardSize?: string;
    demoChildCount?: number;
    drawerLevel?: ArComponentLevels;
    gridSize?: string;
    hasHeader?: boolean;
    hasFooter?: boolean;
    hasDrawer?: boolean;
    hasSidepanel?: boolean;
    isFooterFixed?: boolean;
    selectable?: boolean;
    sidepanelLevel?: ArComponentLevels;
    variant?: ArWebPageLayout;
    [key: string]: any;
}
export type WizardModalProps = ModalProps & WizardProps;
export interface WizardProps extends BaseProps {
    activeStage: number;
    hasOnlyContent?: boolean;
    hideStatusBar?: boolean;
    navigationType?: ArWizardNavigationTypes;
    onStageChange?: FunctionType;
    onComplete: FunctionType;
    onCancel?: FunctionType;
    stages: Array<WizardStage>;
    title?: string;
}
export interface DateRangePickerProps extends FormInputProps {
    closeOnEndSelect?: boolean;
    mask?: ArDateMasks | string;
}
export interface LottieTileProps extends BaseProps {
    preset: PresetDefinition;
    setSelectedPresets: FunctionType;
}
export interface AssetSelectorProps extends BaseProps {
}
export interface AccordionProps extends BaseProps {
    data: Array<AccordionExpansionPanelProps>;
    firstExpanded?: boolean;
    variant?: ArAccordionVariants;
    appearance?: ArAccordionStyles;
    isRemovable?: boolean;
}
export interface AccordionExpansionPanelProps extends BaseProps {
    id: string;
    title: string;
    expanded?: boolean;
    isRemovable?: boolean;
    setExpandedId?: FunctionType;
    content: ReactNode;
}
export interface LottieLayersProps extends BaseProps {
}
export interface LottieEditorToolsProps extends BaseProps {
    setSelectedPresets: FunctionType;
}
export interface LottieEditorProps extends BaseProps {
    selectedPresets?: Array<PresetDefinition>;
}
export interface IconMergeContainerProps extends BaseProps {
    icons: Array<IconResponse>;
}
export interface AdvancedColorPickerProps extends BaseProps {
    displaySample?: boolean;
    id?: string;
    onColorSelect?: (arg: string) => void;
    title?: string;
}
export interface IconEditorProps extends BaseProps {
    layout?: string;
}
export interface IconStyleSelectorProps extends BaseProps {
    iconStyles?: {
        fillColor?: string;
        strokeColor?: string;
        bgColor?: string;
        strokeWidth?: string;
    };
    layout?: string;
    setIconStyles: FunctionType;
}
export interface TilesProps extends BaseProps {
    data: AppNavigatorDataType;
}
export interface PlaygroundTileProps extends BaseProps {
}
export interface ProductDescriptionTileProps extends BaseProps {
    name: string;
    description: Array<string>;
    image: string;
    imagePlacement?: ArPlacement;
    onClick?: FunctionType;
}
export interface LandingContentProps extends BaseProps {
}
export interface FlexToolsProps extends BaseProps {
    isLanding?: boolean;
    route?: string;
}
export interface AppAndToolsSelectorProps extends BaseProps {
    data: Array<AppNavigatorDataType>;
}
export interface AppTileProps extends BaseProps {
    label: string;
    icon: string;
    url?: string;
    onClick?: FunctionType;
    description?: Array<string>;
}
export interface FontTileProps extends BaseProps {
    font: string;
}
export interface FontsListProps extends BaseProps {
}
export interface BubbleChartProps extends BaseProps {
    clickHandler?: FunctionType;
    data: Array<ObjectType>;
}
export interface CronTabProps extends BaseProps {
    onChange: FunctionType;
    value?: ObjectType | string;
}
export interface CarouselProps extends BaseProps {
    ariaLabel?: string | undefined;
    axis: "horizontal" | "vertical";
    autoFocus?: boolean;
    autoPlay?: boolean;
    centerMode?: boolean;
    centerSlidePercentage: number;
    children?: ReactNode;
    className?: string;
    dynamicHeight?: boolean;
    emulateTouch?: boolean;
    infiniteLoop?: boolean;
    interval: number;
    labels: {
        leftArrow: string;
        rightArrow: string;
        item: string;
    };
    noMarkers?: boolean;
    onClickItem: (index: number, item: React.ReactNode) => void;
    onClickThumb: (index: number, item: React.ReactNode) => void;
    onChange: (index: number, item: React.ReactNode) => void;
    onSwipeStart: (event: React.TouchEvent) => void;
    onSwipeEnd: (event: React.TouchEvent) => void;
    onSwipeMove: (event: React.TouchEvent) => boolean;
    preventMovementUntilSwipeScrollTolerance: boolean;
    renderArrowPrev: (clickHandler: () => void, hasPrev: boolean, label: string) => React.ReactNode;
    renderArrowNext: (clickHandler: () => void, hasNext: boolean, label: string) => React.ReactNode;
    renderIndicator: (clickHandler: (e: React.MouseEvent | React.KeyboardEvent) => void, isSelected: boolean, index: number, label: string) => React.ReactNode;
    renderItem: (item: React.ReactNode, options?: {
        isSelected: boolean;
        isPrevious: boolean;
    }) => React.ReactNode;
    renderThumbs: (children: ReactNode) => ReactNode;
    selectedItem: number;
    showArrows: boolean;
    showStatus: boolean;
    showIndicators: boolean;
    showThumbs: boolean;
    statusFormatter: (currentItem: number, total: number) => string;
    stopOnHover: boolean;
    swipeable: boolean;
    swipeScrollTolerance: number;
    thumbWidth?: number;
    transitionTime: number;
    useKeyboardArrows?: boolean;
    verticalSwipe: "natural" | "standard";
    width: number | string;
    animationHandler: "slide" | "fade" | AnimationHandler;
    swipeAnimationHandler: SwipeAnimationHandler;
    stopSwipingHandler: StopSwipingHandler;
}
export interface SwiperProps extends BaseProps {
    tagName?: string;
    className: string;
    style: CSSProperties;
    children?: ReactNode;
    allowMouseEvents?: boolean;
    onMouseDown?: FunctionType;
    onSwipeUp?: FunctionType;
    onSwipeDown?: FunctionType;
    onSwipeLeft?: FunctionType;
    onSwipeRight?: FunctionType;
    onSwipeStart?: FunctionType;
    onSwipeMove?: FunctionType;
    onSwipeEnd?: FunctionType;
    onTouchStart?: FunctionType;
    onTouchEnd?: FunctionType;
    innerRef?: FunctionType;
    tolerance: number;
}
export interface TaskFormProps extends BaseProps {
}
export interface TaskListProps extends BaseProps {
    list?: Array<Task>;
    taskFetcher: FunctionType;
}
export interface TaskLoginPromptProps extends BaseProps {
}
export interface TaskViewerProps extends BaseProps {
    hideSelf: FunctionType;
    isNew?: boolean;
    selectedTask?: Task;
    taskFetcher: FunctionType;
}
export interface NamespaceInfoBoxProps extends BaseProps {
    namespace: Namespace;
}
export interface ConfigRowItemProps extends BaseProps {
    config?: Config;
    disabled?: boolean;
    isNew?: boolean;
    onAdd?: (key: string, value: string) => void;
    onUpdate?: (_id: string, key: string, value: string) => void;
    onDelete?: (_id?: string) => void;
}
export interface NamespaceOrgFormProps extends BaseProps {
    context: string;
}
export interface ConfigurationLoginPromptProps extends BaseProps {
}
export interface ConfigurationNoConfigPromptProps extends BaseProps {
}
export interface ConfigurationViewerProps extends BaseProps {
    namespace: Namespace;
    fetchNamespaces: () => void;
}
export interface ConfigurationListProps extends BaseProps {
    list?: Array<TreeListData>;
}
export interface SegmentProps extends BaseProps {
    isMultiSelect?: boolean;
    onChange?: FunctionType;
    segment: SegmentData;
    segments?: Array<SegmentData>;
    setSegments?: FunctionType;
}
export interface SegmentedControlProps extends BaseProps {
    hasUniformSegments?: boolean;
    isMultiSelect?: boolean;
    onChange: (segment: SegmentData, segments?: Array<SegmentData>) => void;
    segments: Array<SegmentData>;
    selected?: string;
}
export interface BubbleVizProps extends BaseProps {
    data: ArrayType | ObjectType;
}
export interface ArVizProps extends BaseProps {
    clickHandler?: FunctionType;
    type: ArVisualizationTypes;
    data: ArrayType | ObjectType;
}
export interface SuggestionsProps extends BaseProps {
    inSvgString?: boolean;
    suggestions?: Array<ObjectType | string>;
    title?: string;
}
export interface SuggestionProps extends BaseProps {
    suggestion?: ObjectType | string;
    inSvgString?: boolean;
}
export interface IconControllerProps extends BaseProps {
    group?: string;
    name?: string;
    icon?: ObjectType;
}
export interface TagsProps extends BaseProps {
    clickHandler?: FunctionType;
    hideHeader?: boolean;
    label?: string;
    tags?: ObjectType;
}
export interface ColorSelectorProps extends BaseProps {
    label?: string;
    onChange?: FunctionType;
    withSample?: boolean;
}
export interface LoginProviderProps extends BaseProps {
    url?: string;
}
export interface UserOptionsProps extends BaseProps {
    isLanding?: boolean;
    loginProvider?: ArLoginProviders;
    loginUrl?: string;
    onLogout?: FunctionType;
    options: Array<ListItemContent>;
    signUpUrl?: string;
}
export interface FavoritesListProps extends BaseProps {
}
export interface FavoritesItemProps extends BaseProps {
    index: string | number;
    favorite: IconTileProps;
}
export interface SidePanelProps extends BaseProps {
    hideCloseButton?: boolean;
    isFloating?: boolean;
    component?: JSX.Element | null;
    componentName?: string;
    componentProps?: ObjectType;
    header?: ReactNode;
    placement?: ArPlacement;
}
export interface LoaderProps extends BaseProps {
    type?: ArLoaderTypes;
    size?: ArSizes;
    label?: string;
    icon?: string;
    progress?: number;
}
export interface LoadableIconProps extends BaseProps {
    color?: string;
    icon?: string;
    skipPathColorFill?: boolean;
    svgString?: string;
    svgB64String?: string;
    height?: string;
    hoverColor?: string;
    hoverShadow?: boolean;
    isLocal?: boolean;
    onClick?: MouseEventHandler<HTMLImageElement>;
    onMouseEnter?: MouseEventHandler<HTMLImageElement>;
    onMouseLeave?: MouseEventHandler<HTMLImageElement>;
    size?: string;
    toggleColor?: string;
    toggled?: boolean;
    width?: string;
    fillColor?: string;
    strokeColor?: string;
    strokeWidth?: string;
}
export interface IconProps extends BaseProps {
    alt?: string;
    color?: string;
    height?: string;
    onClick?: MouseEventHandler;
    onMouseEnter?: MouseEventHandler;
    onMouseLeave?: MouseEventHandler;
    size?: string;
    src: string;
    width?: string;
}
export interface TabProps extends BaseProps {
    bubbleDimensions?: Function;
    data?: any;
    items?: Array<TabProps>;
    deletable?: boolean;
    icon?: string;
    id?: string;
    isActive?: boolean;
    label: string;
    onHover?: FunctionType;
    onHoverOut?: FunctionType;
    onSelect?: FunctionType;
    size?: string;
    variant?: string;
}
export interface TabBarProps extends BaseProps {
    activeId?: string;
    data: Array<TabProps>;
    onTabSelected?: (id: string, data: any) => void;
    size?: string;
    variant?: string;
    [key: string]: any;
}
export interface AlertProps extends BaseProps {
    closeable?: boolean;
    position?: string;
    show?: boolean;
    type?: ArAlertType;
    message: string;
    timeout?: number;
    uid: string;
}
export interface BrowserIncompatibilityProps extends BaseProps {
    applicationName?: string;
    moreLink?: string;
}
interface LinkBaseProps extends BaseProps {
    to: string;
    onClick?: MouseEventHandler;
    openInNew?: boolean;
    preemptNavigation?: boolean;
}
interface LinkLabelProps extends LinkBaseProps {
    label: string;
}
interface LinkChildrenProps extends LinkBaseProps {
    children: ReactNode;
}
export type LinkProps = (LinkLabelProps & Partial<LinkChildrenProps>) | (Partial<LinkLabelProps> & LinkChildrenProps);
export interface Component_404Props extends BaseProps {
    iconSize?: string;
}
export interface FrameContentProps extends BaseProps {
    contentDefinition: FrameContentDefinition | null;
    notificationProps?: any;
}
export interface TreeListProps extends BaseProps {
    customTooltip?: FunctionType;
    data: Array<TreeListData>;
    firstExpanded?: boolean;
    indentation?: string;
    isDraggable?: boolean;
    noSearch?: boolean;
    onItemSelect?: Function;
    showTooltip?: boolean;
    title?: string;
    withAddButton?: boolean;
}
export interface TreeListItemProps extends BaseProps {
    customTooltip?: FunctionType;
    hierarchyLevel: number;
    data: TreeListData;
    indentation?: number;
    indentationUnit?: string;
    isAddButton?: boolean;
    isDraggable?: boolean;
    onItemSelect?: Function;
    setSelected?: Function;
    selected?: string;
    showTooltip?: boolean;
}
export interface TextInputProps extends FormInputProps {
    action?: FunctionType;
    min?: number;
    max?: number;
    label?: string;
    placeholder?: string;
    subtitle?: string;
    type?: HTMLInputTypeAttribute;
    value?: string | number;
}
export type SliderProps = {
    focussed?: boolean;
    withManual?: boolean;
} & TextInputProps;
export interface IconsListProps extends BaseProps {
    icons?: Array<IconResponse>;
    variant?: string;
}
export interface IconTileProps extends BaseProps {
    hideBorder?: boolean;
    hideFooter?: boolean;
    icon: IconResponse;
    iconSize?: string;
    onClick?: Function;
    selectable?: boolean;
    tools?: Array<ToolItemConfig>;
    toolsPlacement?: string;
    type?: ArIconTileTypes;
    fillColor?: string;
    strokeColor?: string;
    strokeWidth?: string;
}
export interface ButtonProps extends BaseProps {
    content?: string | JSX.Element | undefined;
    color?: string;
    disabled?: boolean;
    preIcon?: string;
    postIcon?: string;
    onClick?: MouseEventHandler<HTMLButtonElement>;
    onMouseEnter?: MouseEventHandler<HTMLButtonElement>;
    onMouseLeave?: MouseEventHandler<HTMLButtonElement>;
    size?: string;
    splitButtonClasses?: string;
    type?: ArButtonTypes;
    variant?: ArButtonVariants;
    splitPopoverVersion?: string;
    splitOptions?: Array<ListItemContent>;
    splitTrigger?: ArPopoverTriggers;
}
export interface DrawerProps extends BaseProps {
    children?: ReactNode;
    collapsed?: boolean;
    contentClasses?: string;
    isCollapsible?: boolean;
    title?: string;
}
export interface PaginationProps extends BaseProps {
    count: number;
    isHeadless?: boolean;
    load: number;
    trigger?: ArPageTriggers;
    maxPillsToShow?: number;
    pageSetter?: FunctionType;
    pageSize?: number;
    data?: Array<PageItem>;
    dataFetcher?: FunctionType;
}
export interface HeaderProps {
    routeDetails?: ObjectType;
    user?: User;
    onLogin?: () => void;
    onLogout?: () => void;
    onCreateAccount?: () => void;
}
export interface PopoverProps extends BaseProps {
    animation?: ArAnimations | Array<ArAnimations>;
    children: Array<JSX.Element | null>;
    contentClasses?: string;
    contentMatchAnchorWidth?: boolean;
    disabled?: boolean;
    hideMarker?: boolean;
    isOpen?: boolean;
    onAnchorClick?: FunctionType;
    position?: ArPopoverPositions;
    popAtPointer?: boolean;
    preserveMarkerSpace?: boolean;
    stretch?: boolean;
    trigger?: ArPopoverTriggers;
    updateTriggers?: Array<any>;
    version?: string;
}
export interface InlineMenuProps extends BaseProps {
    data: {
        [key: string]: any;
    };
    top?: number;
    left?: number;
    ref?: Ref<HTMLDivElement>;
}
export interface ContextMenuProps extends BaseProps {
    children?: string | JSX.Element | Array<JSX.Element>;
    data: {
        [key: string]: any;
    };
}
export interface ListItemProps extends BaseProps {
    actions?: Array<ListActionItem>;
    index: string;
    isMultiSelect?: boolean;
    isRaw?: boolean;
    item: ListItemContent;
    items: Array<ListItemContent>;
    itemClasses?: string;
    selected?: ListItemContent;
    setItems: FunctionType;
    setSelected: FunctionType;
    showCheckBoxes?: boolean;
    variant?: ArListVariants;
}
export interface ListProps extends BaseProps {
    actions?: Array<ListActionItem>;
    data: Array<ListItemContent>;
    isRaw?: boolean;
    isMultiSelect?: boolean;
    itemClasses?: string;
    showCheckBoxes?: boolean;
    variant?: ArListVariants;
}
export interface MainProps {
    contentClasses?: string;
    drawerContent?: ReactNode | false;
    drawerTitle?: string;
    mainContent?: ReactNode | false;
    hideSidepanelCloseButton?: boolean;
    rightPanelContent?: {
        name?: string;
        component?: JSX.Element | null;
        props?: ObjectType;
    } | false;
    leftPanelContent?: {
        name?: string;
        component?: JSX.Element | null;
        props?: ObjectType;
    } | false;
    rightPanelHeader?: ReactNode;
    leftPanelHeader?: ReactNode;
}
export interface DropdownProps extends FormInputProps {
    anchorClasses?: string;
    contentClasses?: string;
    contentMatchAnchorWidth?: boolean;
    context?: string;
    hasBorder?: boolean;
    hideDropdownMarker?: boolean;
    id?: string;
    isMultiSelect?: boolean;
    label?: string;
    onSelectionChanged: FunctionType;
    options?: Array<OptionType>;
    placeholder?: string;
    selected?: Array<PRIMITIVES>;
    showCheckBoxes?: boolean;
    stretch?: boolean;
    subtitle?: string;
    variant?: ArDropdownVariants;
}
export interface ModalProps extends BaseProps {
    body?: ReactNode;
    closeHandler?: FunctionType;
    content?: ReactNode;
    footer?: ReactNode;
    header?: ReactNode;
    isSticky?: boolean;
    primaryButtonLabel?: string;
    primaryHandler?: FunctionType;
    secondaryButtonLabel?: string;
    show?: boolean;
}
export interface BreadcrumbProps extends BaseProps {
    data: Array<BreadCrumbData>;
    separator?: string;
    size?: ArSizes;
    onClick?: Function;
}
export interface BadgeProps extends BaseProps {
    icon?: string;
    size?: ArSizes;
    shadow?: boolean;
    text?: string;
    type?: ArBadgeType;
}
export interface TextAreaProps extends FormInputProps {
    placeholder?: string;
}
export interface DatePickerProps extends FormInputProps {
    allowEventSetting?: boolean;
    placeholder?: string;
}
export interface DateInputProps extends FormInputProps {
    placeholder?: string;
}
export interface DateRangeProps extends FormInputProps {
    alwaysShowCalendars?: boolean;
    applyButtonClasses?: string | Array<string>;
    applyClass?: string | Array<string>;
    autoApply?: boolean;
    autoUpdateInput?: boolean;
    buttonClasses?: string;
    callback?: FunctionType;
    cancelButtonClasses?: string | Array<string>;
    cancelClass?: string | Array<string>;
    dateLimit?: ObjectType;
    drops?: string;
    element?: JSX.Element;
    endDate?: string | Moment;
    isCustomDate?: FunctionType;
    isInvalidDate?: FunctionType;
    isShowing?: boolean;
    leftCalendar?: ObjectType;
    locale?: Locale;
    linkedCalendars?: boolean;
    maxDate?: boolean | Moment;
    maxSpan?: ObjectType;
    maxYear?: string;
    minDate?: boolean | Moment;
    minYear?: string;
    opens?: string;
    parentEl?: string;
    ranges?: {
        [key: string]: Array<Moment>;
    };
    rightCalendar?: ObjectType;
    singleDatePicker?: boolean;
    showDropdowns?: boolean;
    showWeekNumbers?: boolean;
    showISOWeekNumbers?: boolean;
    showCustomRangeLabel?: boolean;
    startDate?: string | Moment;
    timePicker?: boolean;
    timePicker24Hour?: boolean;
    timePickerSeconds?: boolean;
    timePickerIncrement?: number;
    updateElement?: FunctionType;
    updateMonthsInView?: FunctionType;
}
export interface DateProps extends FormInputProps {
    isRangeSelector?: boolean;
    minDate?: Date;
    maxDate?: Date;
    startDate?: Date;
    endDate?: Date;
    showTimePicker?: boolean;
    timePickerSeconds?: boolean;
    is12HourFormat?: boolean;
    showQuickSelectors?: boolean;
    customSelectors?: Array<ListItemProps>;
    showTodayInFooter?: boolean;
    showDropdowns?: boolean;
}
export interface CardProps extends BaseProps {
    children?: ReactNode;
    header?: ReactNode;
}
export interface SelectionPillProps extends BaseProps {
    context?: string;
    data: PageInfoType;
    disabled?: boolean;
    onClick: Function;
    selected?: boolean;
    size?: ArPillSizes;
}
export interface ToggleProps extends FormInputProps {
    id?: string;
    hideStatus?: boolean;
    label?: string;
    stretch?: boolean;
    toggleOnName?: string;
    toggleOffName?: string;
    isOn?: boolean;
    onChange: FunctionType;
}
export interface HeroProps extends BaseProps {
}
export interface CalendarProps extends BaseProps {
    allowEventSetting?: boolean;
    events?: Array<Event>;
    customDayEventSetter?: FunctionType;
    endDate?: Date | DateFormat | CalendarDate;
    hasTimeControls?: boolean;
    isSingleSelect?: boolean;
    maxDate?: Date | DateFormat | CalendarDate;
    minDate?: Date | DateFormat | CalendarDate;
    miniMode?: boolean;
    onDateSelected?: FunctionType;
    startDate?: Date | DateFormat | CalendarDate;
}
export interface MonthNavigatorProps extends BaseProps {
    currentDecade?: number;
    currentMonthNavView?: ArMonthSelectorViews | null;
    currentView: ArCalViews;
    currentYear?: number;
    miniMode?: boolean;
    refDate: Date;
    setCurrentDecade: FunctionType;
    setCurrentMonthNavView: FunctionType;
    setCurrentView: FunctionType;
    setCurrentYear: FunctionType;
    setRefDate: FunctionType;
}
export interface MonthSelectorProps extends BaseProps {
    currentDecade?: number;
    currentMonthNavView?: ArMonthSelectorViews | null;
    currentView: ArCalViews;
    currentYear?: number;
    miniMode?: boolean;
    onMonthSelect: FunctionType;
    setCurrentDecade: FunctionType;
    setCurrentMonthNavView: FunctionType;
    setCurrentView: FunctionType;
    setCurrentYear: FunctionType;
}
export interface JustCalendarProps extends BaseProps {
    allowEventSetting?: boolean;
    calHelper?: CalendarInstance;
    calendar?: Array<CalendarDate | false>;
    endDate?: CalendarDate;
    hovered?: CalendarDate;
    isSingleSelect?: boolean;
    miniMode?: boolean;
    onDateSelected: FunctionType;
    setHovered: FunctionType;
    startDate?: CalendarDate;
}
export interface DateItemProps extends JustCalendarProps {
    date: CalendarDate;
    isToday: boolean;
}
export interface EventManagerProps extends BaseProps {
    events?: Array<Event>;
    miniMode?: boolean;
    onEventSubmit: FunctionType;
    selectedDate: CalendarDate;
    setCurrentView: FunctionType;
}
export interface EventFormProps extends BaseProps {
    miniMode?: boolean;
    onSubmit: FunctionType;
    selectedDate: CalendarDate;
}
export interface EventListProps extends BaseProps {
    events?: Array<Event>;
}
export interface CheckboxProps extends FormInputProps {
    id?: string;
    label?: string;
    type?: CheckBoxTypes;
    onChange: FunctionType;
}
export interface ColorPickerProps extends BaseProps {
    id?: string;
    label?: string;
    onChange?: Function;
    value?: string;
}
export interface PasswordProps extends BaseProps {
    onChange: FunctionType;
}
export interface PillProps extends BaseProps {
    label: string | JSX.Element;
    data?: any;
    deletable?: boolean;
    onClick?: Function;
    onDelete?: Function;
}
export interface PillboxProps extends BaseProps {
    classes?: string;
    data: Array<PillProps>;
    isDeletable?: boolean;
    onChange: Function;
    placeholder?: ReactNode;
}
export interface DetailsPanelProps extends BaseProps {
}
export interface DialogProps extends BaseProps {
}
export interface FacetedFilterProps extends BaseProps {
}
export interface LabelValueProps extends BaseProps {
    label?: string;
    value?: string;
    variant?: ArLabelValueVariants;
}
export interface LearnLinkProps extends BaseProps {
}
export interface MaskProps extends BaseProps {
}
export interface NotificationProps extends BaseProps {
}
export interface NumericStepperProps extends BaseProps {
}
export interface PickerRangeProps extends BaseProps {
}
export interface PicklistProps extends BaseProps {
}
export interface ProgressIndicatorProps extends BaseProps {
    progress?: number;
}
export interface ProgressStepperProps extends BaseProps {
}
export interface RadioProps extends FormInputProps {
}
export type SearchFieldProps = TypeAheadProps & {
    dataApi?: string;
    searchApi?: string;
};
export interface SecondaryNavigationProps extends BaseProps {
}
export interface SelectProps extends FormInputProps {
    context?: string;
    id?: string;
    label?: string;
    onSelectionChanged: FunctionType;
    options?: Array<OptionType>;
    selected?: string;
}
export interface SplitterProps extends BaseProps {
}
export interface TableProps extends BaseProps {
    columns: Array<Column<TableRowItem>>;
    data: Array<TableRowItem>;
    layout?: ArTableLayouts;
}
export interface TagProps extends BaseProps {
}
export interface TimeEntryProps extends FormInputProps {
    is24Hour?: boolean;
}
export interface ToolbarProps extends BaseProps {
}
export type TooltipProps = BaseProps & {
    children: Array<ReactElement>;
} & Partial<PopoverV2Props>;
export interface TypeAheadProps extends FormInputProps {
    categories?: Array<OptionType>;
    categoryPlaceholder?: string;
    hidePopup?: boolean;
    items: Array<SearchItem>;
    inputValue?: string;
    isMultiSelect?: boolean;
    itemRenderer?: (item: SearchItem) => ReactNode;
    label?: string;
    placeholder?: string;
    searchKeys?: string | Array<string>;
    onChange?: (event: ChangeEvent<HTMLInputElement>, filteredItems: Array<SearchItem> | null, typedValue: string) => void;
    onItemSelected?: (item: SearchItem, filteredItems: Array<SearchItem> | SearchItem | null) => void;
    outsourceMultiSelections?: boolean;
    value?: Array<SearchItem> | null;
}
export interface UploaderProps extends BaseProps {
}
export interface WidgetProps extends BaseProps {
    actions?: Array<WidgetActionItem>;
    header?: string;
    content?: ReactNode;
    noPadContent?: boolean;
}
export interface AboutUsProps extends BaseProps {
}
export interface AlertStackManagerProps extends BaseProps {
}
export interface AlphabetFilterProps extends BaseProps {
}
export interface ApplicationProps extends BaseProps {
}
export interface BannerProps extends BaseProps {
}
export interface BenefitsProps extends BaseProps {
}
export interface BlogProps extends BaseProps {
}
export interface BrandsProps extends BaseProps {
}
export interface BreadcrumbsProps extends BaseProps {
}
export interface CareersProps extends BaseProps {
}
export interface CategoryFilterProps extends BaseProps {
}
export interface ContactProps extends BaseProps {
}
export interface ContentProps extends BaseProps {
}
export interface CookiesProps extends BaseProps {
}
export interface CtaProps extends BaseProps {
}
export interface DashboardProps extends BaseProps {
}
export interface DownloadProps extends BaseProps {
}
export interface EcommOrdersProps extends BaseProps {
}
export interface EcommProductsProps extends BaseProps {
}
export interface EmptyProps extends BaseProps {
}
export interface ErrorBoundaryProps extends BaseProps {
}
export interface FaqProps extends BaseProps {
}
export interface FeaturesProps extends BaseProps {
}
export interface FiltersProps extends BaseProps {
}
export interface FooterProps extends BaseProps {
}
export interface FormProps extends BaseProps {
}
export interface GalleryProps extends BaseProps {
}
export interface GraphProps extends BaseProps {
}
export interface GraphTilesProps extends BaseProps {
}
export interface HowItWorksProps extends BaseProps {
}
export interface HttpCodeProps extends BaseProps {
}
export interface InstaPhotosProps extends BaseProps {
}
export interface IntegrationsProps extends BaseProps {
}
export interface LogoCloudsProps extends BaseProps {
}
export interface NewsletterProps extends BaseProps {
}
export interface NotificationsProps extends BaseProps {
}
export interface PortfolioProps extends BaseProps {
}
export interface PricingProps extends BaseProps {
}
export interface ProductInfoProps extends BaseProps {
}
export interface ProjectsProps extends BaseProps {
}
export interface ReviewsProps extends BaseProps {
}
export interface RichTextProps extends BaseProps {
}
export interface ServicesProps extends BaseProps {
}
export interface SignInUpProps extends BaseProps {
}
export interface SnackbarProps extends BaseProps {
}
export interface StatsProps extends BaseProps {
}
export interface StepsProps extends BaseProps {
}
export interface TeamProps extends BaseProps {
}
export interface TestimonialsProps extends BaseProps {
}
export interface ToastProps extends BaseProps {
}
export interface UsersProps extends BaseProps {
}
export {};
