import { MONTH_INDEX as k } from "../config/constants.js";
import { ArDateFormats as u } from "../types/enums.js";
import "./dateformat.js";
import "./domHelper.js";
import "./adapters.js";
import b from "./helper.js";
import "../transform-df96e507.js";
import "../config/api-config.js";
import "react";
import "react/jsx-runtime";
import "./recursionHelper.js";
import "../v4-333bbb31.js";
const f = (a, t) => ("" + a).substring(2) + (t || ""), g = (a, t, e) => {
  const r = k[a];
  return (t ? r.substring(0, 4) : r) + (e || "");
};
class M {
  /**
   * Calendar constructor
   *
   * @param  options  Calendar options
   */
  constructor({
    startDate: t = null,
    endDate: e = null,
    siblingMonths: r = !1,
    weekNumbers: s = !1,
    weekStart: o = 0
  } = {}) {
    this.startDate = t, this.endDate = e, this.siblingMonths = r, this.weekNumbers = s, this.weekStart = o;
  }
  /**
   * Calculate a calendar month
   *
   * @param   year   Year
   * @param   month  Month [0-11]
   * @return         Calendar days
   */
  getCalendar(t, e) {
    const r = new Date(Date.UTC(t, e, 1, 0, 0, 0, 0));
    t = r.getFullYear(), e = r.getMonth();
    const s = [], o = r.getDay(), n = -((7 - this.weekStart + o) % 7), D = M.daysInMonth(t, e), w = (D - n) % 7, p = M.daysInMonth(t, e - 1);
    let i = n, y, c, l = !1, m = null, h, Y;
    const T = D - i + (w !== 0 ? 7 - w : 0) + n;
    for (; i < T; )
      c = i + 1, y = ((i < 1 ? 7 + i : i) + o) % 7, c < 1 || c > D ? this.siblingMonths ? (c < 1 ? (h = e - 1, Y = t, h < 0 && (h = 11, Y--), c = p + c) : c > D && (h = e + 1, Y = t, h > 11 && (h = 0, Y++), c = i - D + 1), h !== void 0 && Y !== void 0 && (l = {
        day: c,
        weekDay: y,
        month: h,
        year: Y,
        siblingMonth: !0
      })) : l = !1 : l = {
        day: c,
        weekDay: y,
        month: e,
        year: t
      }, l && this.weekNumbers && (m === null ? m = M.calculateWeekNumber(l) : y === 1 && m === 52 ? m = 1 : y === 1 && m++, l.weekNumber = m), l && this.startDate && (l.selected = this.isDateSelected(l)), s.push(l), i++;
    return s;
  }
  /**
   * Checks if a date is selected
   *
   * @param   date  Date object
   * @return        Selected status of the date
   */
  isDateSelected(t, e) {
    if (!this.startDate || e === null)
      return !1;
    let r = this.startDate;
    return e ? M.compare(this.startDate, e) === 1 && (r = e, e = this.startDate) : e = this.endDate, t.year === r.year && t.month === r.month && t.day === r.day ? !0 : !(!e || t.year === r.year && t.month === r.month && t.day < r.day || t.year === e.year && t.month === e.month && t.day > e.day || t.year === r.year && t.month < r.month || t.year === e.year && t.month > e.month || t.year < r.year || t.year > e.year);
  }
  /**
   * Sets the selected period start
   *
   * @param  date  Date object
   */
  setStartDate(t) {
    this.startDate = t;
  }
  /**
   * Sets the selected period end
   *
   * @param  date  Date object
   */
  setEndDate(t) {
    this.endDate = t;
  }
  /**
   * Sets one selected date
   *
   * @param  date  Date object
   */
  setDate(t) {
    return this.setStartDate(t);
  }
  /**
   * Calculates the difference between two dates (date1 - date2), in days
   *
   * @param   dateLeft   Date object
   * @param   dateRight  Date object
   * @return             Days between the dates
   */
  static diff(t, e) {
    const r = new Date(
      Date.UTC(t.year, t.month, t.day, 0, 0, 0, 0)
    ), s = new Date(
      Date.UTC(e.year, e.month, e.day, 0, 0, 0, 0)
    );
    return Math.ceil(
      (r.getTime() - s.getTime()) / 864e5
    );
  }
  /**
   * Calculates the interval between two dates
   *
   * @param   dateLeft   Date object
   * @param   dateRight  Date object
   * @return             Number of days between dates
   */
  static interval(t, e) {
    return Math.abs(M.diff(t, e)) + 1;
  }
  /**
   * Quickly compare two dates
   *
   * @param   dateLeft   Left `CalendarDate` object
   * @param   dateRight  Right `CalendarDate` object
   * @return             Comparison result: -1 (left < right), 0 (equal) or 1 (left > right)
   */
  static compare(t, e) {
    if (typeof t != "object" || typeof e != "object" || t === null || e === null)
      throw new TypeError("dates must be objects");
    return t.year < e.year ? -1 : t.year > e.year ? 1 : t.month < e.month ? -1 : t.month > e.month ? 1 : t.day < e.day ? -1 : t.day > e.day ? 1 : 0;
  }
  /**
   * Calculates the number of days in a month
   *
   * @param   year  Year
   * @param   month Month [0-11]
   * @return        Length of the month
   */
  static daysInMonth(t, e) {
    return new Date(t, e + 1, 0).getDate();
  }
  /**
   * Calculates if a given year is a leap year
   *
   * @param   year  Year
   * @return        Leap year or not
   */
  static isLeapYear(t) {
    return t % 4 === 0 && t % 100 !== 0 || t % 400 === 0;
  }
  /**
   * Calculates the week number for a given date
   *
   * @param   date  Date object
   * @return        Week number
   */
  // Adapted from http://techblog.procurios.nl/k/news/view/33796/14863/calculate-iso-8601-week-and-year-in-javascript.html
  static calculateWeekNumber(t) {
    const e = new Date(
      Date.UTC(t.year, t.month, t.day, 0, 0, 0, 0)
    ), r = new Date(e.valueOf()), s = (e.getUTCDay() + 6) % 7;
    r.setUTCDate(r.getUTCDate() - s + 3);
    const o = r.valueOf();
    return r.setUTCMonth(0, 1), r.getUTCDay() !== 4 && r.setUTCMonth(0, 1 + (4 - r.getUTCDay() + 7) % 7), 1 + Math.ceil((o - r.getTime()) / 6048e5);
  }
  static toString(t, e = "/", r = "DDMMYYYY") {
    const s = b.pad(t.day, e), o = b.pad(t.month + 1, e), n = t.year;
    switch (r) {
      case u.MMDDYY:
        return o + s + f(n);
      case u.DDMMYYYY:
        return s + o + n;
      case u.MMDDYYYY:
        return o + s + n;
      case u.DDMMMYY:
        return s + g(t.month + 1, !0, e) + f(n);
      case u.DDMMMYYYY:
        return s + g(t.month + 1, !0, e) + n;
      case u.MMMDDYY:
        return g(t.month + 1, !0, e) + s + f(n);
      case u.MMMDDYYYY:
        return g(t.month + 1, !0, e) + s + n;
      case u.YYMMDD:
        return f(n) + o + s;
      case u.YYMMMDD:
        return f(n) + g(t.month + 1, !0, e) + s;
      case u.YYYYMMDD:
        return n + o + s;
      case u.YYYYMMMDD:
        return n + g(t.month + 1, !0, e) + s;
      case u.DDMMYY:
      default:
        return s + o + f(n);
    }
  }
  static getPreviousMonth(t) {
    const e = t.getMonth(), r = t.getFullYear(), s = e === 0 ? 11 : e - 1, o = e === 0 ? r - 1 : r, n = /* @__PURE__ */ new Date();
    return n.setDate(t.getDate()), n.setMonth(s), n.setFullYear(o), n;
  }
  static getNextMonth(t) {
    const e = t.getMonth(), r = t.getFullYear(), s = e === 11 ? 0 : e + 1, o = e === 11 ? r + 1 : r, n = /* @__PURE__ */ new Date();
    return n.setDate(t.getDate()), n.setMonth(s), n.setFullYear(o), n;
  }
  static getPreviousYear(t) {
    const e = t.getFullYear(), r = /* @__PURE__ */ new Date();
    return r.setDate(t.getDate()), r.setMonth(t.getMonth()), r.setFullYear(e === 1 ? 1 : e - 1), r;
  }
  static getNextYear(t) {
    const e = t.getFullYear(), r = /* @__PURE__ */ new Date();
    return r.setDate(t.getDate()), r.setMonth(t.getMonth()), r.setFullYear(e + 1), r;
  }
}
const I = (a, t, e, r = "AM") => {
  if (t) {
    let s = t;
    return r === "PM" && t !== 12 ? s += 12 : r === "AM" && t === 12 && (s = 0), new Date(
      a.year,
      a.month,
      a.day,
      s,
      e
    );
  } else
    return new Date(a.year, a.month, a.day);
}, O = (a, t) => {
  var n, D;
  const e = (n = t.schedule) == null ? void 0 : n.starts, r = (D = t.schedule) == null ? void 0 : D.ends, s = e && {
    day: e.getDate(),
    month: e.getMonth(),
    year: e.getFullYear()
  }, o = r && {
    day: r.getDate(),
    month: r.getMonth(),
    year: r.getFullYear()
  };
  if (s && o) {
    const w = M.compare(a, s), p = M.compare(a, o), i = r == null ? void 0 : r.toLocaleString("en-US", { hour12: !0 }).split(" ")[2], y = r.getHours() === 0 && i === "AM" && a.day === o.day;
    return w >= 0 && p <= 0 && !y;
  }
  return !1;
};
export {
  M as default,
  O as isWithinSchedule,
  f as sub,
  I as toDate
};
