/// <reference types="react" />
import { CarouselProps, LoadableIconProps } from "../types/components.interface";
import { ArPopoverPositions } from "../types";
declare class DOMHelper {
    static style: CSSStyleDeclaration;
    static fontSize: number;
    static markerSize: number;
    static implementSvgStyles(svg: SVGSVGElement, svgProps?: LoadableIconProps, flags?: Array<boolean>): SVGSVGElement;
    static svgStringToBase64(svgString: string, svgProps?: LoadableIconProps, flags?: Array<boolean>): string | null;
    static svgStringToElement(svgString: string): SVGSVGElement | null;
    static svgToBase64(svg: SVGSVGElement | string | null, svgProps?: LoadableIconProps, flags?: Array<boolean>): string;
    static outerWidth(el: HTMLElement): number;
    static translate(position: number, metric: "px" | "%", axis: "horizontal" | "vertical"): string;
    static hexToHsl(color: string, returnRaw?: boolean): string | (number | undefined)[];
    static hexToRgb(color: string): number[];
    /**
     * Converts an RGB color value to HSL. Conversion formula
     * adapted from http://en.wikipedia.org/wiki/HSL_color_space.
     * Assumes r, g, and b are contained in the set [0, 255] and
     * returns h, s, and l in the set [0, 1].
     *
     * @param   Number  r       The red color value
     * @param   Number  g       The green color value
     * @param   Number  b       The blue color value
     * @return  Array           The HSL representation
     */
    static rgbToHsl(r: number, g: number, b: number, returnRaw?: boolean): string | (number | undefined)[];
    static hslToRgb(h: number, s: number, l: number): number[];
    static rgbToHex(r: number, g: number, b: number): string;
    static hslToHex(h: number, s: number, l: number): string;
    static downloadSvg(svgString: string, svgName: string, svgProps?: LoadableIconProps): void;
    /**
     * Gets the list 'position' relative to a current index
     * @param index
     */
    static getPosition(index: number, props: CarouselProps): number;
    /**
     * Sets the 'position' transform for sliding animations
     * @param position
     * @param forceReflow
     */
    static setPosition(position: number, axis: "horizontal" | "vertical"): React.CSSProperties;
    static isKeyboardEvent(e?: React.MouseEvent | React.KeyboardEvent): e is React.KeyboardEvent;
    static getDocumentElement(demo?: boolean): Document | null;
    static getWindowElement(demo?: boolean): Window | null;
    static shouldUsePosition(position: ArPopoverPositions, anchorRect: DOMRect, popoverRect: DOMRect, demo?: boolean): false | ArPopoverPositions;
    static adjustPosition(position: ArPopoverPositions, anchorRect: DOMRect, popoverRect: DOMRect, hideMarker?: boolean): {
        left: string | number;
        top: string | number;
    };
    static getPositionToUse(anchorRect: DOMRect, popoverRect: DOMRect, requestedPosition?: ArPopoverPositions, demo?: boolean): ArPopoverPositions;
    static calculatePopoverPosition(anchorRect: DOMRect, popoverRect: DOMRect, requestedPosition?: ArPopoverPositions, hideMarker?: boolean, clickCoordinates?: Array<number> | null, demo?: boolean): {
        leftTop: {
            top: string | number;
            left: string | number;
        };
        position: ArPopoverPositions;
    };
    static openInNewTab(url: string): void;
}
export default DOMHelper;
